SubtreeRpcData

Type Alias SubtreeRpcData 

pub type SubtreeRpcData = NoteCommitmentSubtreeData<String>;
A subtree data type that can hold Sapling or Orchard subtree roots.

Aliased Type

pub struct SubtreeRpcData {
    pub root: String,
    pub end_height: Height,
}

Fields

root: String

Merkle root of the 2^16-leaf subtree.

end_height: Height

Height of the block containing the note that completed this subtree.

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 32 bytes